<?php
/*************************************************************
 *
 * Domain Module Class - bNamed.net
 *
 ************************************************************/

class bnamed extends DomainModule {

    
    // INFO Displayed on the module management section
    protected $description='Module to manage domain name registrations through bNamed.net';


    /*
     * This variable will be auto-loaded by HostBill before any action will be taken by module.
     */
    protected $client_data=array();
  
    protected $configuration = array(
       'username'=>array(
            'value'=>'',
             'type'=>'input',
            'default'=>false
        ),
       'password'=>array(
            'value'=>'',
             'type'=>'password',
            'default'=>false
        )
    );
     /*
      * Translation of the configuration fields
     */
    protected $lang=array(
        'english'=>array(
            'username'=>'UID',
            'password'=>'Password',
        )
    );

	    /*
	     * please REMOVE ALL UNNECESARRY COMMANDS
	     */
	    //protected $commands = array('Register', 'Transfer', 'Renew', 'ContactInfo', 'DNSmanagement', 'EmailForwarding', 'RegisterNameServers', 'EppCode');
	    protected $commands = array('Register', 'Transfer', 'Renew', 'ContactInfo');

		public function synchInfo() {
	        $params = array(
	            'sld' => $this->options['sld'],
	            'tld' => $this->options['tld']
	        );

	        $out = $this->Send('GetDomain', $params);
	        $return = array();
			if($out) {
				$return['expires'] = date('Y-m-d', strtotime($out->Result->ExpirationISO));                    // Expiry date: yyyy-mm-dd format
				switch ($out->Result->StatusCode)
				{
					case "A":
					case "ANS":
						$return['status'] = "Active";
						break;
					case "N2":
						$return['status'] = "Pending Registration";
						break;
					case "B2":
					case "B3":
					case "B4":
					case "B5":
					case "T2":
					case "T3":
					case "TQ2":
						$return['status'] = "Pending Transfer";
						break;
				}
			    $return['ns'] = explode(",", $out->Result->DNSList);
			}

			return $return;
	    }


	    private function Send($action, $params) {
	        // We are creating POST request:
	        $post = "uid=".$this->configuration['username']['value'];
	        $post .= "&key=".urlencode($this->configuration['password']['value']);
	        $post .= "&command=".$action;
	        if(is_array($params)) {
	            foreach($params as $key => $val) {
	                $post .= "&{$key}=".urlencode($val);
	            }
	        }

	        $curl = curl_init();                                // we are using cURL library here
	        curl_setopt($curl, CURLOPT_URL, "https://www.bNamed.net/nl/api.asp?".$post);
	        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
	        curl_setopt($curl, CURLOPT_TIMEOUT, 360);
	        curl_setopt($curl, CURLOPT_POST, false);             // API uses POST method
	        //curl_setopt($curl, CURLOPT_POSTFIELDS, $post);
	        $out = curl_exec($curl);
	        if($out === false) {
	            $this->addError(ucwords(curl_error($curl)));
	        }
	        curl_close($curl);
	        $resp = simplexml_load_string($out);                          // API returns data encoded in XML
	        if($resp->ErrorCode == 0) {
	           return $resp;
	        } else {
	           echo('An error occured: '.$resp->ErrorText." (ErrorCode = ".$resp->ErrorCode.")"); // addError() method is used to display error in the HostBill.
	           return false;
	        }
	    }

	    public function Register() {
	        // all required parameters for successfull domain registration.
	        $params = array(
	            'sld' => $this->options['sld'],
	            'tld' => $this->options['tld'],
	            'PurchaseType' => 'N',
	            'NumYears' => $this->options['numyears'],
	            'DNSType' => 'E',
	            'DNSList' => $this->options['ns1'].','.$this->options['ns2'].','.$this->options['ns3'].','.$this->options['ns4'],
	            'LicenseeNr' => '-2',
	            'LicenseeFirstName' => $this->client_data['firstname'],
	            'LicenseeName' => $this->client_data['lastname'],
	            'LicenseeCompany' => $this->client_data['companyname'],
	            'LicenseeStreet' => $this->client_data['address1'],
	            'LicenseeResidence' => $this->client_data['city'],
	            'LicenseeCountry' => $this->client_data['country'],
	            'LicenseePostCode' => $this->client_data['postcode'],
	            'LicenseeEMail' => $this->client_data['email'],
	            'LicenseePhone' => $this->client_data['phonenumber'],
	            'OnSiteNr' => $this->configuration['username']['value'],
	            'ExtendType' => '-1'
	        );

	        $out = $this->Send('purchase', $params);          // get response from the server

	        if($out) { // SUCCESS !!!

	            // change status of the domain !
	            $this->addDomain('Active');
	            $this->addInfo('Domain has been registered');            
	            return true;

	        } else {
	            $this->addError('There was a problem while registering the domain.');
	            return false;
	        }
	    }


	    public function Transfer() {
	        $params = array(
	            'sld' => $this->options['sld'],
	            'tld' => $this->options['tld'],
	            'PurchaseType' => 'B',
	            'NumYears' => $this->options['numyears'],
	            'DNSType' => 'E',
	            'DNSList' => $this->options['ns1'].','.$this->options['ns2'].','.$this->options['ns3'].','.$this->options['ns4'],
	            'LicenseeNr' => '-2',
	            'LicenseeFirstName' => $this->client_data['firstname'],
	            'LicenseeName' => $this->client_data['lastname'],
	            'LicenseeCompany' => $this->client_data['companyname'],
	            'LicenseeStreet' => $this->client_data['address1'],
	            'LicenseeResidence' => $this->client_data['city'],
	            'LicenseeCountry' => $this->client_data['country'],
	            'LicenseePostCode' => $this->client_data['postcode'],
	            'LicenseeEMail' => $this->client_data['email'],
	            'LicenseePhone' => $this->client_data['phonenumber'],
	            'OnSiteNr' => $this->configuration['username']['value'],
	            'ExtendType' => '-1',
	            'AuthKey' => $this->options['epp_code']                  // EPP Code is usually required
	        );


	        $out = $this->Send('purchase', $params);          // get response from the server


	        if($out) {
	            $this->addDomain('Pending Transfer');
	            $this->addInfo('Domain transfer has been initiated');
	            return true;

	        } else {
	            $this->addError('There was a problem while transfering the domain.');
	            return false;
	        }
	    }


	    public function Renew() {
	        $params = array(
	            'sld' => $this->options['sld'],
	            'tld' => $this->options['tld'],
	            'NumYears' => $this->options['numyears']
	        );

	        $out = $this->Send('extend', $params);          // get response from the server

	        if($out) { // SUCCESS !!!
	            $this->addPeriod();                        // This method is
	            $this->addInfo('Domain has been renewed');
	            return true;

	        } else {
	            $this->addError('Domain renewal failed');
	            return false;
	        }
	    }

	    public function getNameServers() {
	        $params = array(
	            'sld' => $this->options['sld'],
	            'tld' => $this->options['tld']
	        );

	        $out = $this->Send('GetDomain', $params);
	        if($out) {
	            // just a simple array with the nameservers of the domain
	            return explode(",", $out->Result->DNSList);
	        } else {
	            $this->addError('Unable to get Name Servers');
	        }
	    }


	    public function updateNameServers() {
	        $params = array(
	            'sld' => $this->options['sld'],
	            'tld' => $this->options['tld'],
				'dnstype' => "E",
	            'DNSList' => $this->options['ns1'].','.$this->options['ns2'].','.$this->options['ns3'].','.$this->options['ns4']
	        );


	        $out = $this->Send('Update', $params);

	        if($out) {
	            $this->addInfo('NameServers have been updated');
	            return true;
	        } else {
	            $this->addError('Action failed');
	            return false;
	        }
	    }


	    /*
	     * (OPTIONAL) public function getContactInfo():array.
	     * return array with the structure like in example below
	     *
	     */
	   public function getContactInfo() {
	        $params = array(
	            'sld' => $this->options['sld'],
	            'tld' => $this->options['tld']
	        );

	        $out = $this->Send('GetDomain', $params);

	        if($out) {
	            return array(
	                    'registrant'=>array(
	                            'firstname' => $out->Result->Licensee->FirstName,
	                            'lastname' => $out->Result->Licensee->Name,
	                            'companyname' => $out->Result->Licensee->Company,
	                            'email' => $out->Result->Licensee->EMail,
	                            'address1' => $out->Result->Licensee->Street,
	                            'address2' => 'disabled',              // this field will be disabled
	                            'city' => $out->Result->Licensee->Residence,
	                            'state' => 'disabled',
	                            'postcode' => $out->Result->Licensee->Postcode,
	                            'country' => $out->Result->Licensee->Country,
	                            'phonenumber' => $out->Result->Licensee->Phone
	                        ),
	                        'tech'=>array(
	                            'firstname' => $out->Result->OnSite->FirstName,
	                            'lastname' => $out->Result->OnSite->Name,
	                            'companyname' => $out->Result->OnSite->Company,
	                            'email' => $out->Result->OnSite->EMail,
	                            'address1' => $out->Result->OnSite->Street,
	                            'address2' => 'disabled',              // this field will be disabled
	                            'city' => $out->Result->OnSite->Residence,
	                            'state' => 'disabled',
	                            'postcode' => $out->Result->OnSite->Postcode,
	                            'country' => $out->Result->OnSite->Country,
	                            'phonenumber' => $out->Result->OnSite->Phone
	                        ),
	                        'billing'=>array(

	                        ),
	                        'admin'=>array(

	                        )
			);
	        } else {
	            $this->addError('Unable to get contact info.');
	            return false;
	        }
	    }


	    public function updateContactInfo() {
	        $params = array(
	            'sld' => $this->options['sld'],
	            'tld' => $this->options['tld'],


	            'LicenseeNr' => '-2',
	            'LicenseeFirstName' => $this->options['registrant']['firstname'],
	            'LicenseeName' => $this->options['registrant']['lastname'],
	            'LicenseeCompany' => $this->options['registrant']['companyname'],
	            'LicenseeStreet' => $this->options['registrant']['address1'],
	            'LicenseeResidence' => $this->options['registrant']['city'],
	            'LicenseeCountry' => $this->options['registrant']['country'],
	            'LicenseePostCode' => $this->client_data['postcode'],
	            'LicenseeEMail' => $this->options['registrant']['email'],
	            'LicenseePhone' => $this->options['registrant']['phonenumber'],
	            'OnSiteNr' => '-2',
	            'OnSiteFirstName' => $this->options['tech']['firstname'],
	            'OnSiteName' => $this->options['tech']['lastname'],
	            'OnSiteCompany' => $this->options['tech']['companyname'],
	            'OnSiteStreet' => $this->options['tech']['address1'],
	            'OnSiteResidence' => $this->options['tech']['city'],
	            'OnSiteCountry' => $this->options['tech']['country'],
	            'OnSitePostCode' => $this->client_data['postcode'],
	            'OnSiteEMail' => $this->options['tech']['email'],
	            'OnSitePhone' => $this->options['tech']['phonenumber'],
	            'AdminNr' => '-2',
	            'AdminFirstName' => $this->options['admin']['firstname'],
	            'AdminName' => $this->options['admin']['lastname'],
	            'AdminCompany' => $this->options['admin']['companyname'],
	            'AdminStreet' => $this->options['admin']['address1'],
	            'AdminResidence' => $this->options['admin']['city'],
	            'AdminCountry' => $this->options['admin']['country'],
	            'AdminPostCode' => $this->client_data['postcode'],
	            'AdminEMail' => $this->options['admin']['email'],
	            'AdminPhone' => $this->options['admin']['phonenumber']
	        );

	        $out = $this->Send('Update', $params);

	        if($out) { // SUCCESS !
	            $this->addInfo('Contact Info has been updated');
	            return true;
	        } else {
	            $this->addError('Action failed');
	            return false;
	        }
	    }


	}
	?>